@@ -243,6 +243,13 @@ impl ConfigSerializer {
             offset,
             extractor_code
         );
+        impl_item_read!(
+            BUTTON_INDEX_EXTRACTOR_CODE,
+            ButtonIndexExtractor,
+            data,
+            offset,
+            extractor_code
+        );
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -276,6 +283,12 @@ impl ConfigSerializer {
             data,
             extractor
         );
+        impl_item_write!(
+            BUTTON_INDEX_EXTRACTOR_CODE,
+            ButtonIndexExtractor,
+            data,
+            extractor
+        );
         Err(ConfigSerializerError::UnknownExtractor)
     }
 
@@ -348,6 +361,27 @@ impl ConfigSerializer {
             offset,
             filter_code
         );
+        impl_item_read!(
+            U8_IS_EQUAL_FILTER_CODE,
+            U8IsEqualFilter,
+            data,
+            offset,
+            filter_code
+        );
+        impl_item_read!(
+            U8_SET_STATE_FILTER_CODE,
+            U8SetStateFilter,
+            data,
+            offset,
+            filter_code
+        );
+        impl_item_read!(
+            U8_SET_STATE_FROM_VALUE_FILTER_CODE,
+            U8SetFromValueStateFilter,
+            data,
+            offset,
+            filter_code
+        );
         Err(ConfigSerializerError::UnknownFilter)
     }
 
@@ -385,6 +419,9 @@ impl ConfigSerializer {
             filter
         );
         impl_item_write!(BOOL_SET_STATE_FILTER_CODE, BoolSetStateFilter, data, filter);
+        impl_item_write!(U8_IS_EQUAL_FILTER_CODE, U8IsEqualFilter, data, filter);
+        impl_item_write!(U8_SET_STATE_FILTER_CODE, U8SetStateFilter, data, filter);
+        impl_item_write!(U8_SET_STATE_FROM_VALUE_FILTER_CODE, U8SetFromValueStateFilter, data, filter);
         Err(ConfigSerializerError::UnknownFilter)
     }
 
